@@ -1,5 +1,4 @@
 from tg import expose, flash, require, request, response, redirect, tmpl_context, validate
-from tg.controllers import CUSTOM_CONTENT_TYPE
 from pylons.i18n import ugettext as _, lazy_ugettext as l_
 from pylons.controllers.util import abort
 from repoze.what import predicates
@@ -26,6 +25,12 @@ from libacr.model.core import DBSession, User, Group
 from libacr.model.content import Tag, Content, Slice, ContentData, Page
 from libacr.model.user_permission import AcrUserPermission
 
+try:
+    from sets import Set as set
+    from sets import ImmutableSet as frozenset
+except:
+    pass
+
 import mimetypes, base64
 
 __all__ = ['AdminController']
@@ -135,15 +140,17 @@ class AdminController(BaseAdminController):
     @require(predicates.in_group("acr"))
     def tag_members(self, **kw):
         tag = DBSession.query(Tag).filter_by(name=kw['tag']).one()
-        contents=tag.contents
-        props=[]
-        i_props = ''
-        for i in contents:
+        contents=[]
+        props=set()
+        
+        for i in tag.contents:
             i_props = i.data_instance._properties
             section = i_props.sections()[0]
-            for p in i_props.options(section):
-                    if p not in props:
-                        props.append(p)
+
+            data = dict(i_props.items(section))
+            props |= frozenset(data.keys())
+            contents.append(dict(item=i, data=data, binaries=[p for p,v in data.iteritems() if v.startswith('data:')]))
+        
         return dict(tag=tag, props=props, contents=contents, section_title="Tags")
 
     @expose()
