@@ -4,7 +4,7 @@ from lib import rdisk_url, icons, language
 import genshi
 import urllib2
 import pkg_resources
-import logging
+import logging, traceback, sys
 
 from libacr.model.core import DBSession
 from libacr.model.content import Page, Slice
@@ -62,6 +62,8 @@ def preview_slice(page, slice):
         try:
             result += renderer.preview(page, slice, slice.content.data)
         except Exception, e:
+            tb = traceback.extract_tb(sys.exc_info()[2])
+            log.warning(''.join(traceback.format_list(tb)))
             result += str(e)
     else:
         result += u'<div class="acr_wrong_view">Unsupported View Type</div>'
@@ -82,6 +84,11 @@ def render_slice(page, slice):
         result += u'''<div class="acr_edit_container">
                         <div class="acr_edit_button">
                           <div style="float:left;">
+                            <a href="#"
+                               onclick="jQuery(this).parents('.acr_edit_container').hide(); return false;">
+                                hide
+                            </a>
+                            &nbsp;
                             <a href="'''+acr_move_slice(slice.uid, -1)+u'''">&lt;</a>
                             '''+str(slice.slice_order)+u'''
                             <a href="'''+acr_move_slice(slice.uid, 1)+u'''">&gt;</a>
@@ -99,6 +106,8 @@ def render_slice(page, slice):
         try:
             result += renderer.render(page, slice, slice.content.data)
         except Exception, e:
+            tb = traceback.extract_tb(sys.exc_info()[2])
+            log.warning(''.join(traceback.format_list(tb)))
             result += str(e)
     else:
         result += u'<div class="acr_wrong_view">Unsupported View Type</div>'
@@ -125,14 +134,14 @@ def user_in_group(group):
     return request.identity and (group in request.identity['groups'])
 
 def slicegroup_filter(slice):
+    from libacr.views.manager import ViewsManager
+
     if not slice.content or not slice.content.data:
         return ''
 
-    import ConfigParser, StringIO
-    config = ConfigParser.ConfigParser({'preview':'0', 'size':'0', 'type':'div'})
     try:
-        config.readfp(StringIO.StringIO(slice.content.data))
-        return config.get('group', 'filter_tag')
+        config = ViewsManager.find_view('slicegroup').to_dict(slice.content.data)
+        return config.get('filter_tag')
     except:
         return 'Invalid SliceGroup'
 
@@ -183,7 +192,6 @@ def render_slices_menu(page):
 
     from views.manager import ViewsManager
     html = '<ul id="acr_slices_menu">'
-    html += rdisk_slices_menu_entries(page)
     for view in ViewsManager.all_views:
         if view.exposed == True:
             html += """<li class="acr_slices_menu_entry">
@@ -192,17 +200,6 @@ def render_slices_menu(page):
     html += '</ul>'
     return genshi.Markup(html)
 
-def rdisk_slices_menu_entries(page):
-    from views.manager import ViewsManager
-    html = ''
-    if config.get('rdisk_root'):
-        for view in ViewsManager.rdisk_views:
-            html += """
-<li class="acr_slices_menu_entry">
-    <a href="%s">%s</a>
-</li>""" % (rdisk_url('/upload', params=dict(view=view.name, page=page and page.uid)), view.name)
-    return html
-
 def check_latest_release():
     try:
         libac_url = "http://pypi.python.org/pypi/libacr/"
