@@ -1,6 +1,7 @@
-from tg import tmpl_context
+from tg import tmpl_context, request
 from libacr.lib import url as acr_url
 from libacr.lib import language
+from libacr.form_fields import AcrOtherSingleSelectField
 from genshi.template import MarkupTemplate
 
 from libacr.model.core import DBSession
@@ -13,7 +14,7 @@ class MenuRenderer(EncodedView):
     def __init__(self):
         self.name = 'menu'
         self.exposed = True
-        self.form_fields = [twf.SingleSelectField('root', label_text="Menu Root:", default='root',
+        self.form_fields = [AcrOtherSingleSelectField('root', label_text="Menu Root:", default='root',
                                                           options=(('parent', 'Parent Page'),
                                                                    ('root', 'Site Root'),
                                                                    ('current', 'Viewed Page'))),
@@ -34,6 +35,9 @@ class MenuRenderer(EncodedView):
                 if m_page.getattr('hidden'):
                     continue
 
+                if not m_page.is_visible(request.identity):
+                    continue
+
                 if m_page.slices and m_page.slices[0].view == 'link':
                     uri = m_page.slices[0].content.data
                 elif m_page.getattr('link'):
@@ -50,7 +54,7 @@ class MenuRenderer(EncodedView):
                     style = 'class="acr_menu_selected"'
                 else:
                     style= ''
-                menu += '<li %s><a href="%s">%s</a>' % (style, uri, m_page.title)
+                menu += '<li %s><a href="%s">%s</a>' % (style, uri, m_page.i18n_title)
                 
                 if max_depth > level:
                     menu += recursive_render_menu(max_depth, m_page.children, level+1)
